pushNativeRouteForResult method

Future<Object?> pushNativeRouteForResult(
  1. PageSettings page
)

Like pushNativeRoute, but completes with the result the native screen passes to its handler completion (null when it finishes without one).

The value is in wire encoding; generated native routes with a result type expose a typed pushForResult() that decodes it.

Implementation

Future<Object?> pushNativeRouteForResult(PageSettings page) {
  return _hostApi.pushNativeRouteForResult(page);
}